Introduction
============

This directory contains example described in the document `Introduction.md` 
in the main directory of the DHParser-package. The examples is a simple
domain specific notation for encoding poems.

